@@ -8,6 +8,8 @@
 
 #define GAMEOVER_TEXT_LEN 5
 
+extern mod_header m;
+
 void write_score(u16* map, u16 map_width, u16 x, u16 y, int val, int pad)
 {
 	char buf[pad];
@@ -49,9 +51,12 @@ int game_run()
 {
 	Bg bg, starbg;
 	game g;
+	
+	u16 channels[4];
+
 	s32 loop;
 	u16* temp;
-	int score;
+	int score, i, mod_pause=0;
 	int die = 0;
 	char foo[100];
 
@@ -128,6 +133,15 @@ int game_run()
 	g.alien_bullets_num = 10;
 	g.alien_bullets = aliens_create_bullets(g.alien_bullets_num);
 
+	/* allocate channels */
+	for(i=0; i<4; i++)
+	{
+		channels[i] = sfxSystemAllocChannel();
+	}
+	m.master_volume = 12;
+
+	sfxSystemInit();
+
 	/* main game loop */
 	while(!die)
 	{
@@ -168,12 +182,20 @@ int game_run()
 		
 		sprintf(foo, "%d\n", REG_TM0D);
 		//print(foo);
-		process_soundbuffer();
+
+		if(mod_pause == 3)
+		{
+			mod_play(&m, channels);
+			mod_pause = 0;
+		}
+		mod_pause++;
+		
+		sfxSystemWorker();
 		gba_vsync();
 	}
 
 	/* we're dead - do the "game over" thang */
-	play_sound(&exp_sample);
+	sfxSystemPlay(&exp_sample);
 	for(loop=0; loop < PLAYER_EXPLODE_SPEED * EXPLOSION_FRAMES_NUM; loop++)
 	{
 		aliens_draw(&g);
@@ -181,7 +203,13 @@ int game_run()
 		playership_draw(&g);
 		
 		CopyOAM();
-		process_soundbuffer();
+		if(mod_pause == 3)
+		{
+			mod_play(&m, channels);
+			mod_pause = 0;
+		}
+		mod_pause++;
+		sfxSystemWorker();
 		gba_vsync();
 	}
 	
@@ -207,6 +235,15 @@ int game_run()
 		playership_draw(&g);
 		
 		CopyOAM();
+		
+		m.master_volume = 12 - ((loop+16) * 12 / (80-8+16));
+		if(mod_pause == 3)
+		{
+			mod_play(&m, channels);
+			mod_pause = 0;
+		}
+		mod_pause++;
+		sfxSystemWorker();
 		gba_vsync();
 	}
 
@@ -218,9 +255,17 @@ int game_run()
 		playership_draw(&g);
 		
 		CopyOAM();
+		sfxSystemWorker();
 		gba_vsync();
 	}
 
+	for(i=0; i<4; i++)
+	{
+		sfxSystemFreeChannel(channels[i]);
+	}
+
+	sfxSystemStop();
+
 	/* do a neat mosaic fade effect */
 	REG_BG1CNT |= BG_MOSAIC_ENABLE;
 	REG_BG2CNT |= BG_MOSAIC_ENABLE;
